=== modified file 'drizzled/table_share.h'
--- drizzled/table_share.h	2010-03-16 03:28:36 +0000
+++ drizzled/table_share.h	2010-03-16 17:52:35 +0000
@@ -38,6 +38,11 @@
 
 typedef drizzled::hash_map<std::string, TableShare *> TableDefinitionCache;
 
+const static std::string STANDARD_STRING("STANDARD");
+const static std::string TEMPORARY_STRING("TEMPORARY");
+const static std::string INTERNAL_STRING("INTERNAL");
+const static std::string FUNCTION_STRING("FUNCTION");
+
 class TableShare
 {
 public:
@@ -208,6 +213,14 @@
     return table_name.str;
   }
 
+  const std::string &getTableName(std::string &name_arg) const
+  {
+    name_arg.clear();
+    name_arg.append(table_name.str, table_name.length);
+
+    return name_arg;
+  }
+
   const char *getSchemaName() const
   {
     return db.str;
@@ -246,19 +259,19 @@
   message::Table *table_proto;
 public:
 
-  const char * getTableTypeAsString() const
+  const std::string &getTableTypeAsString() const
   {
     switch (table_proto->type())
     {
     default:
     case message::Table::STANDARD:
-      return "STANDARD";
+      return STANDARD_STRING;
     case message::Table::TEMPORARY:
-      return "TEMPORARY";
+      return TEMPORARY_STRING;
     case message::Table::INTERNAL:
-      return "INTERNAL";
+      return INTERNAL_STRING;
     case message::Table::FUNCTION:
-      return "FUNCTION";
+      return FUNCTION_STRING;
     }
   }
 

=== modified file 'plugin/schema_dictionary/tests/r/data_dictionary.result'
--- plugin/schema_dictionary/tests/r/data_dictionary.result	2010-03-15 21:50:05 +0000
+++ plugin/schema_dictionary/tests/r/data_dictionary.result	2010-03-16 17:52:35 +0000
@@ -211,8 +211,6 @@
 #
 #
 #
-#
-#
 SELECT count(*) FROM REFERENTIAL_CONSTRAINTS;
 count(*)
 #

=== modified file 'plugin/table_cache_dictionary/table_cache.cc'
--- plugin/table_cache_dictionary/table_cache.cc	2010-03-16 03:28:36 +0000
+++ plugin/table_cache_dictionary/table_cache.cc	2010-03-16 17:52:35 +0000
@@ -33,8 +33,6 @@
   add_field("SESSION_ID", plugin::TableFunction::NUMBER);
   add_field("TABLE_SCHEMA");
   add_field("TABLE_NAME");
-  add_field("ARCHETYPE");
-  add_field("ENGINE");
   add_field("VERSION", plugin::TableFunction::NUMBER);
   add_field("IS_NAME_LOCKED", plugin::TableFunction::BOOLEAN);
   add_field("ROWS", plugin::TableFunction::NUMBER);
@@ -112,7 +110,7 @@
 {
   /**
     For test cases use:
-    --replace_column 1 #  6 # 8 # 9 # 10 # 11 #
+    --replace_column 1 # 4 # 5 #  6 # 8 # 9 #
   */
 
   /* SESSION_ID 1 */
@@ -126,29 +124,23 @@
   push(table->getShare()->getSchemaName(arg));
 
   /* TABLE_NAME  3 */
-  push(table->getShare()->getTableName());
-
-  /* ARCHETYPE  4 */
-  push(table->getShare()->getTableTypeAsString());
-
-  /* ENGINE 5 */
-  push(table->getEngine()->getName());
-
-  /* VERSION 6 */
+  push(table->getShare()->getTableName(arg));
+
+  /* VERSION 4 */
   push(static_cast<int64_t>(table->getShare()->version));
 
-  /* IS_NAME_LOCKED 7 */
+  /* IS_NAME_LOCKED 5 */
   push(table->getShare()->isNameLock());
 
-  /* ROWS 8 */
+  /* ROWS 6 */
   push(static_cast<uint64_t>(table->getCursor().records()));
 
-  /* AVG_ROW_LENGTH 9 */
+  /* AVG_ROW_LENGTH 7 */
   push(table->getCursor().rowSize());
 
-  /* TABLE_SIZE 10 */
+  /* TABLE_SIZE 8 */
   push(table->getCursor().tableSize());
 
-  /* AUTO_INCREMENT 11 */
+  /* AUTO_INCREMENT 9 */
   push(table->getCursor().getNextInsertId());
 }

=== modified file 'plugin/table_cache_dictionary/table_definition_cache.cc'
--- plugin/table_cache_dictionary/table_definition_cache.cc	2010-03-16 03:28:36 +0000
+++ plugin/table_cache_dictionary/table_definition_cache.cc	2010-03-16 17:52:35 +0000
@@ -103,7 +103,7 @@
   push(share->getSchemaName(arg));
 
   /* TABLE_NAME  2 */
-  push(share->getTableName());
+  push(share->getTableName(arg));
 
   /* VERSION 3 */
   push(static_cast<int64_t>(share->getVersion()));

=== modified file 'plugin/table_cache_dictionary/tests/r/table_cache.result'
--- plugin/table_cache_dictionary/tests/r/table_cache.result	2010-03-16 01:56:17 +0000
+++ plugin/table_cache_dictionary/tests/r/table_cache.result	2010-03-16 17:52:35 +0000
@@ -4,8 +4,6 @@
   `SESSION_ID` bigint NOT NULL DEFAULT '0',
   `TABLE_SCHEMA` varchar(64) NOT NULL DEFAULT '',
   `TABLE_NAME` varchar(64) NOT NULL DEFAULT '',
-  `ARCHETYPE` varchar(64) NOT NULL DEFAULT '',
-  `ENGINE` varchar(64) NOT NULL DEFAULT '',
   `VERSION` bigint NOT NULL DEFAULT '0',
   `IS_NAME_LOCKED` varchar(5) NOT NULL DEFAULT '',
   `ROWS` bigint NOT NULL DEFAULT '0',
@@ -17,16 +15,16 @@
 count(*)
 #
 flush tables;
-select * FROM data_dictionary.TABLE_CACHE ORDER BY TABLE_SCHEMA, TABLE_NAME, ARCHETYPE;
-SESSION_ID	TABLE_SCHEMA	TABLE_NAME	ARCHETYPE	ENGINE	VERSION	IS_NAME_LOCKED	ROWS	AVG_ROW_LENGTH	TABLE_SIZE	AUTO_INCREMENT
-#	#	table_cache	FUNCTION	FunctionEngine	#	FALSE	#	#	#	#
+select * FROM data_dictionary.TABLE_CACHE ORDER BY TABLE_SCHEMA, TABLE_NAME;
+SESSION_ID	TABLE_SCHEMA	TABLE_NAME	VERSION	IS_NAME_LOCKED	ROWS	AVG_ROW_LENGTH	TABLE_SIZE	AUTO_INCREMENT
+#	data_dictionary	table_cache	#	#	#	595	#	#
 create table a ( a int);
 create table b ( b int);
 select * FROM a,b;
 a	b
-select * FROM data_dictionary.TABLE_CACHE ORDER BY TABLE_SCHEMA, TABLE_NAME, ARCHETYPE;
-SESSION_ID	TABLE_SCHEMA	TABLE_NAME	ARCHETYPE	ENGINE	VERSION	IS_NAME_LOCKED	ROWS	AVG_ROW_LENGTH	TABLE_SIZE	AUTO_INCREMENT
-#	#	table_cache	FUNCTION	FunctionEngine	#	FALSE	#	#	#	#
-#	#	a	STANDARD	InnoDB	#	FALSE	#	#	#	#
-#	#	b	STANDARD	InnoDB	#	FALSE	#	#	#	#
+select * FROM data_dictionary.TABLE_CACHE ORDER BY TABLE_SCHEMA, TABLE_NAME;
+SESSION_ID	TABLE_SCHEMA	TABLE_NAME	VERSION	IS_NAME_LOCKED	ROWS	AVG_ROW_LENGTH	TABLE_SIZE	AUTO_INCREMENT
+#	data_dictionary	table_cache	#	#	#	595	#	#
+#	test	a	#	#	#	6	#	#
+#	test	b	#	#	#	6	#	#
 DROP TABLES a,b;

=== modified file 'plugin/table_cache_dictionary/tests/t/table_cache.test'
--- plugin/table_cache_dictionary/tests/t/table_cache.test	2010-03-16 01:56:17 +0000
+++ plugin/table_cache_dictionary/tests/t/table_cache.test	2010-03-16 17:52:35 +0000
@@ -5,14 +5,13 @@
 
 flush tables;
 
---replace_column 1 # 2 #  6 # 8 # 9 # 10 # 11 #
-select * FROM data_dictionary.TABLE_CACHE ORDER BY TABLE_SCHEMA, TABLE_NAME, ARCHETYPE;
+--replace_column 1 # 4 # 5 #  6 # 8 # 9 #
+select * FROM data_dictionary.TABLE_CACHE ORDER BY TABLE_SCHEMA, TABLE_NAME;
 
 create table a ( a int);
 create table b ( b int);
---replace_column 1 # 2 #  6 # 8 # 9 # 10 # 11 #
 select * FROM a,b;
---replace_column 1 # 2 #  6 # 8 # 9 # 10 # 11 #
-select * FROM data_dictionary.TABLE_CACHE ORDER BY TABLE_SCHEMA, TABLE_NAME, ARCHETYPE;
+--replace_column 1 # 4 # 5 #  6 # 8 # 9 #
+select * FROM data_dictionary.TABLE_CACHE ORDER BY TABLE_SCHEMA, TABLE_NAME;
 
 DROP TABLES a,b;

=== modified file 'tests/r/data_dictionary_like_info.result'
--- tests/r/data_dictionary_like_info.result	2010-03-15 21:50:05 +0000
+++ tests/r/data_dictionary_like_info.result	2010-03-16 17:52:35 +0000
@@ -192,7 +192,7 @@
  or DATA_TYPE = 'varchar')
 group by DATA_TYPE order by DATA_TYPE, num;
 DATA_TYPE	group_concat(table_schema, '.', table_name)	num
-VARCHAR	data_dictionary.CHARACTER_SETS,data_dictionary.CHARACTER_SETS,data_dictionary.CHARACTER_SETS,data_dictionary.COLLATIONS,data_dictionary.COLLATIONS,data_dictionary.COLLATIONS,data_dictionary.COLLATIONS,data_dictionary.COLLATIONS,data_dictionary.COLUMNS,data_dictionary.COLUMNS,data_dictionary.COLUMNS,data_dictionary.COLUMNS,data_dictionary.COLUMNS,data_dictionary.COLUMNS,data_dictionary.COLUMNS,data_dictionary.COLUMNS,data_dictionary.COLUMNS,data_dictionary.COLUMNS,data_dictionary.COLUMNS,data_dictionary.COLUMNS,data_dictionary.COLUMNS,data_dictionary.COLUMNS,data_dictionary.COLUMNS,data_dictionary.COLUMNS,data_dictionary.GLOBAL_STATEMENTS,data_dictionary.GLOBAL_STATEMENTS,data_dictionary.GLOBAL_STATUS,data_dictionary.GLOBAL_STATUS,data_dictionary.GLOBAL_VARIABLES,data_dictionary.GLOBAL_VARIABLES,data_dictionary.INDEXES,data_dictionary.INDEXES,data_dictionary.INDEXES,data_dictionary.INDEXES,data_dictionary.INDEXES,data_dictionary.INDEXES,data_dictionary.INDEXES,data_dictionary.INDEXES,data_dictionary.INDEX_PART	141
+VARCHAR	data_dictionary.CHARACTER_SETS,data_dictionary.CHARACTER_SETS,data_dictionary.CHARACTER_SETS,data_dictionary.COLLATIONS,data_dictionary.COLLATIONS,data_dictionary.COLLATIONS,data_dictionary.COLLATIONS,data_dictionary.COLLATIONS,data_dictionary.COLUMNS,data_dictionary.COLUMNS,data_dictionary.COLUMNS,data_dictionary.COLUMNS,data_dictionary.COLUMNS,data_dictionary.COLUMNS,data_dictionary.COLUMNS,data_dictionary.COLUMNS,data_dictionary.COLUMNS,data_dictionary.COLUMNS,data_dictionary.COLUMNS,data_dictionary.COLUMNS,data_dictionary.COLUMNS,data_dictionary.COLUMNS,data_dictionary.COLUMNS,data_dictionary.COLUMNS,data_dictionary.GLOBAL_STATEMENTS,data_dictionary.GLOBAL_STATEMENTS,data_dictionary.GLOBAL_STATUS,data_dictionary.GLOBAL_STATUS,data_dictionary.GLOBAL_VARIABLES,data_dictionary.GLOBAL_VARIABLES,data_dictionary.INDEXES,data_dictionary.INDEXES,data_dictionary.INDEXES,data_dictionary.INDEXES,data_dictionary.INDEXES,data_dictionary.INDEXES,data_dictionary.INDEXES,data_dictionary.INDEXES,data_dictionary.INDEX_PART	139
 Warnings:
 Warning	1260	1 line(s) were cut by GROUP_CONCAT()
 create table t1(f1 char(1) not null, f2 char(9) not null);

=== modified file 'tests/t/warnings_engine_disabled-master.opt'
--- tests/t/warnings_engine_disabled-master.opt	2008-12-19 21:59:48 +0000
+++ tests/t/warnings_engine_disabled-master.opt	2010-03-16 17:52:35 +0000
@@ -1,1 +0,0 @@
---loose-skip-plugin-ndbcluster

